/* extractLOR.cpp
 *
 * ROOT MACRO
 * 
 * Sample Root macro to extract the LOR from the ROOT output and 
 * to calculate the coordinates of the location of the annihilation
 * between electron and positron
 *
 */

{
	gROOT->Reset();
	
#include "Riostream.h"
#include "math.h"
	
	Int_t i, nevents;	//index i and number of event
	Float_t         globalPosX1, globalPosX2, globalPosY1, globalPosY2, globalPosZ1, globalPosZ2;
	Float_t         sourcePosX1, sourcePosX2, sourcePosY1, sourcePosY2, sourcePosZ1, sourcePosZ2;
	Double_t        time1, time2;
	Int_t			comptonPhantom1, comptonCrystal1, RayleighPhantom1, RayleighCrystal1;
	Int_t			comptonPhantom2, comptonCrystal2, RayleighPhantom2, RayleighCrystal2;
	ofstream fout;	//output file
	fout.open("./output.txt");	//store the Line Of Response (LOR) in the file lor.txt
	
	TFile *f = new TFile("./input.root");	//replace "input.root" by your root file
	TTree *t = f->Get("Coincidences");	//this is where you tell it what "tree" you want to access: coincidences, singles, or I don't know what else
	
	//here, you get the address of all the info you want (but you don't get the actual values yet)
	//Coincidences->SetBranchStatus("*",0);
	Coincidences->SetBranchAddress("globalPosX1",&globalPosX1);
	Coincidences->SetBranchAddress("globalPosX2",&globalPosX2);
	Coincidences->SetBranchAddress("globalPosY1",&globalPosY1);
	Coincidences->SetBranchAddress("globalPosY2",&globalPosY2);
	Coincidences->SetBranchAddress("globalPosZ1",&globalPosZ1);
	Coincidences->SetBranchAddress("globalPosZ2",&globalPosZ2);
	Coincidences->SetBranchAddress("sourcePosX1",&sourcePosX1);
	Coincidences->SetBranchAddress("sourcePosX2",&sourcePosX2);
	Coincidences->SetBranchAddress("sourcePosY1",&sourcePosY1);
	Coincidences->SetBranchAddress("sourcePosY2",&sourcePosY2);
	Coincidences->SetBranchAddress("sourcePosZ1",&sourcePosZ1);
	Coincidences->SetBranchAddress("sourcePosZ2",&sourcePosZ2);
	Coincidences->SetBranchAddress("time1",&time1);
	Coincidences->SetBranchAddress("time2",&time2);
	Coincidences->SetBranchAddress("comptonPhantom1",&comptonPhantom1);
	Coincidences->SetBranchAddress("comptonCrystal1",&comptonCrystal1);
	Coincidences->SetBranchAddress("RayleighPhantom1",&RayleighPhantom1);
	Coincidences->SetBranchAddress("RayleighCrystal1",RayleighCrystal1);
	Coincidences->SetBranchAddress("comptonPhantom2",&comptonPhantom2);
	Coincidences->SetBranchAddress("comptonCrystal2",&comptonCrystal2);
	Coincidences->SetBranchAddress("RayleighPhantom2",&RayleighPhantom2);
	Coincidences->SetBranchAddress("RayleighCrystal2",RayleighCrystal2);

	/*NOTE: the "name" of the info you want (e.g. "globalPosX1", or "time1") can be found in the root file;
	 1) Open the root file in root: root yourRootFile.root
	 2) Type: TBrowser t
	 3) Navigate to your root file and open it
	 4) Go into the Coincidences directory ("tree", in the root lingo)
	 5) All the "leaves" you see are the information stored for each coincidence; this is where the "globalPosX1" and "time1" come from
	 */
	
	nevents = t->GetEntries();	//total number of events in order to loop adequately over all events
	cout << "Number of events = " << nevents << "\n";
	
	Int_t numScatter = 0;
	for (i = 0; i < nevents; i++) {
		t->GetEntry(i);	//here, you're accessing event #i; all your variables from above now get the values desired
		
		//you can get the scatter fraction if you want
		//if ( comptonPhantom1 > 0 || RayleighPhantom1 > 0
		//	|| comptonPhantom2 > 0 || RayleighPhantom2 > 0) {
		if ( comptonPhantom1 > 0 || comptonPhantom2 > 0 ) {
			++numScatter;
		}
		
		//you can also calculate where the annihilation occurred
		//first, find the centre of the LOR
		double xCentre, yCentre, zCentre;
		xCentre = (globalPosX1 + globalPosX2)/2;
		yCentre = (globalPosY1 + globalPosY2)/2;
		zCentre = (globalPosZ1 + globalPosZ2)/2;
		
		//then create a directional vector parallel to the LOR
		double dx, dy, dz;
		dx = globalPosX1 - globalPosX2;
		dy = globalPosY1 - globalPosY2;
		dz = globalPosZ1 - globalPosZ2;
		
		//normalize the vector
		double norm = sqrt(dx*dx + dy*dy + dz*dz);
		dx /= norm;
		dy /= norm;
		dz /= norm;
		
		//now calculate the annihilation point using the time-of-flight (TOF, called deltaTime here, in picoseconds) information
		double c = 299792458.; //speed of light in vacuum
		double annihilationDist = deltaTime*(1.e-12)*c*1000. / 2;	//annihilation distance from the centre of the LOR
		double annihilationPtX = xCentre + (annihilationDist * dx);	//x coordinate of annihilation location
		double annihilationPtY = yCentre + (annihilationDist * dy);	//y coordinate of annihilation location
		double annihilationPtZ = zCentre + (annihilationDist * dz);	//z coordinate of annihilation location
		
		//write these values to a .txt file
		fout << globalPosX1 << "\t" << globalPosY1 << "\t" << globalPosZ1 << "\t";
		fout << globalPosX2 << "\t" << globalPosY2 << "\t" << globalPosZ2 << "\t";
		fout << comptonPhantom1 << "\t" << RayleighPhantom1 << "\t";
		fout << comptonPhantom2 << "\t" << RayleighPhantom2 << "\t";
		fout << time1 << "\t" << time2 << "\t";
		fout << annihilationPtX << "\t" << annihilationPtY << "\t" << annihilationPtZ << "\t";
		
	}
	
		cout << "Scatter fraction = " << (double)numScatter / nevents << "\n";
		
	fout.close();
}